@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Generate walking basslines
 
-our $VERSION = '0.0204';
+our $VERSION = '0.0205';
 
 use Data::Dumper::Compact qw(ddc);
 use Carp qw(croak);
@@ -17,6 +17,13 @@ use strictures 2;
 use namespace::clean;
 
 
+has guitar => (
+    is  => 'ro',
+    isa => sub { croak 'not a boolean' unless $_[0] =~ /^[01]$/ },
+    default => sub { 0 },
+);
+
+
 has intervals => (
     is  => 'ro',
     isa => sub { croak 'not an array reference' unless ref $_[0] eq 'ARRAY' },
@@ -51,7 +58,7 @@ sub generate {
     $chord ||= 'C';
     $num ||= 4;
 
-    print "* CHORD: $chord\n" if $self->verbose;
+    print "CHORD: $chord\n" if $self->verbose;
 
     my $scale = $self->scale->($chord);
 
@@ -117,6 +124,10 @@ sub generate {
         push @fixed, $p;
     }
 
+    if ($self->guitar) {
+        @fixed = map { $_ < 40 ? $_ + 12 : $_ } @fixed;
+    }
+
     # DEBUGGING:
     my @named;
     if ($self->verbose) {
@@ -158,7 +169,7 @@ MIDI::Bassline::Walk - Generate walking basslines
 
 =head1 VERSION
 
-version 0.0204
+version 0.0205
 
 =head1 SYNOPSIS
 
@@ -190,6 +201,14 @@ list.
 
 =head1 ATTRIBUTES
 
+=head2 guitar
+
+  $guitar = $bassline->guitar;
+
+Transpose notes below C<E2> (C<40>) up an octave.
+
+Default: C<0>
+
 =head2 intervals
 
   $verbose = $bassline->intervals;
@@ -223,8 +242,9 @@ Alternatives:
   sub { '' }
 
 The first walks the chromatic scale no matter what the chord.  The
-second walks only the major or minor pentatonic scale.  The last walks
-only the notes of the chord (no scale).
+second walks either the major or minor pentatonic scale, plus the
+notes of the chord.  The last walks only the notes of the chord (no
+scale).
 
 =head2 verbose
 
